@@ -17,13 +17,12 @@ sub _sendToGLPI {
 	my ( $self, $message ) = @_;
 
 	my $response = $self->{taskobj}->{glpi_client}->sendRequest(
-		"url"   => $self->{taskobj}->{agent}->{config}->{armadito}->{server} . "/api/states",
+		"url"   => $self->{taskobj}->{agent}->{config}->{server}[0] . "/api/states",
 		message => $message,
 		method  => "POST"
 	);
 
 	if ( $response->is_success() ) {
-		$self->{taskobj}->_handleResponse($response);
 		$self->{taskobj}->{logger}->info("Send ArmaditoAV State successful...");
 	}
 	else {
@@ -37,7 +36,12 @@ sub _sendToGLPI {
 sub run {
 	my ( $self, %params ) = @_;
 
-	$self->{taskobj}->{jobj}->{task}->{obj} = $self->{jobj};
+	my $obj = {
+		dbinfo    => $self->{jobj},
+		avdetails => []
+	};
+
+	$self->{taskobj}->{jobj}->{task}->{obj} = $obj;
 	my $json_text = to_json( $self->{taskobj}->{jobj} );
 	print "JSON formatted str : \n" . $json_text . "\n";
 
