@@ -3,17 +3,8 @@ package Armadito::Agent::Task::Alerts;
 use strict;
 use warnings;
 use base 'Armadito::Agent::Task';
-
-use FusionInventory::Agent::Config;
-use FusionInventory::Agent::Logger;
-use Data::Dumper;
 use JSON;
-
-sub isEnabled {
-	my ($self) = @_;
-
-	return 1;
-}
+use Data::Dumper;
 
 sub new {
 	my ( $class, %params ) = @_;
@@ -26,20 +17,11 @@ sub new {
 
 	my $task = {
 		name      => "Alerts",
-		antivirus => ""
+		antivirus => $self->{agent}->{antivirus}->getJobj()
 	};
 
 	$self->{jobj}->{task} = $task;
-
-	return $self;
-}
-
-sub _handleResponse {
-	my ( $self, $response ) = @_;
-
-	$self->{logger}->info( "Successful Response : " . $response->content() );
-	my $obj = from_json( $response->content(), { utf8 => 1 } );
-	$self->{logger}->info( Dumper($obj) );
+	$self->{glpi_url} = $self->{agent}->{config}->{server}[0];
 
 	return $self;
 }
@@ -54,12 +36,29 @@ sub _handleError {
 	return $self;
 }
 
-sub run {
-	my ( $self, %params ) = @_;
+sub _sendAlerts {
+	my ( $self, $alerts ) = @_;
 
-	$self = $self->SUPER::run(%params);
+	$self->{jobj}->{task}->{obj} = $alerts;
 
-	return $self;
+	my $json_text = to_json( $self->{jobj} );
+	$self->{logger}->debug($json_text);
+
+	my $response = $self->{glpi_client}->sendRequest(
+		"url"   => $self->{glpi_url} . "/api/alerts",
+		message => $json_text,
+		method  => "POST"
+	);
+
+	if ( $response->is_success() ) {
+		$self->{logger}->info("Alerts successful...");
+	}
+	else {
+		$self->_handleError($response);
+		$self->{logger}->info("Alerts failed...");
+	}
+
+	return 1;
 }
 
 1;
@@ -76,10 +75,6 @@ This task inherits from L<Armadito::Agent::Task>. Get Antivirus alerts and send
 
 =head1 FUNCTIONS
 
-=head2 isEnabled ( $self )
-
-Returns true if the task is enabled.
-
 =head2 run ( $self, %params )
 
 Run the task.
