@@ -4,18 +4,10 @@ use strict;
 use warnings;
 use base 'Armadito::Agent::Task';
 
-use FusionInventory::Agent::Config;
-use FusionInventory::Agent::Logger;
 use Armadito::Agent::Storage;
 use Data::Dumper;
 use JSON;
 
-sub isEnabled {
-	my ($self) = @_;
-
-	return 1;
-}
-
 sub new {
 	my ( $class, %params ) = @_;
 
@@ -27,7 +19,7 @@ sub new {
 
 	my $task = {
 		name      => "Getjobs",
-		antivirus => ""
+		antivirus => $self->{agent}->{antivirus}->getJobj()
 	};
 
 	$self->{jobj}->{task} = $task;
@@ -83,6 +75,24 @@ sub run {
 
 	$self = $self->SUPER::run(%params);
 
+	my $response = $self->{glpi_client}->sendRequest(
+		"url" => $self->{agent}->{config}->{server}[0] . "/api/jobs",
+		args  => {
+			antivirus => $self->{jobj}->{task}->{antivirus}->{name},
+			agent_id  => $self->{jobj}->{agent_id}
+		},
+		method => "GET"
+	);
+
+	if ( $response->is_success() ) {
+		$self->_handleResponse($response);
+		$self->{logger}->info("Getjobs successful...");
+	}
+	else {
+		$self->_handleError($response);
+		$self->{logger}->info("Getjobs failed...");
+	}
+
 	return $self;
 }
 
@@ -100,10 +110,6 @@ This task inherits from L<Armadito::Agent::Task>. Send a pull GET request to get
 
 =head1 FUNCTIONS
 
-=head2 isEnabled ( $self )
-
-Returns true if the task is enabled.
-
 =head2 run ( $self, %params )
 
 Run the task.
