@@ -4,18 +4,12 @@ use strict;
 use warnings;
 use base 'Armadito::Agent::Task';
 
-use FusionInventory::Agent::Config;
-use FusionInventory::Agent::Logger;
 use Armadito::Agent::Storage;
 use Data::Dumper;
+use MIME::Base64;
+use Try::Tiny;
 use JSON;
 
-sub isEnabled {
-	my ($self) = @_;
-
-	return 1;
-}
-
 sub new {
 	my ( $class, %params ) = @_;
 
@@ -27,7 +21,7 @@ sub new {
 
 	my $task = {
 		name      => "Runjobs",
-		antivirus => ""
+		antivirus => $self->{agent}->{antivirus}->getJobj()
 	};
 
 	$self->{jobj}->{task} = $task;
@@ -71,17 +65,7 @@ sub _rmJobFromStorage {
 sub _sortJobsByPriority {
 	my ($self) = @_;
 
-	@{ $self->{jobs} } = sort { $a->{job_priority} <=> $b->{job_priority} } @{ $self->{jobs} };
-
-	return $self;
-}
-
-sub _handleResponse {
-	my ( $self, $response ) = @_;
-
-	$self->{logger}->info( "Successful Response : " . $response->content() );
-	my $obj = from_json( $response->content(), { utf8 => 1 } );
-	$self->{logger}->info( Dumper($obj) );
+	@{ $self->{jobs} } = reverse sort { $a->{job_priority} <=> $b->{job_priority} } @{ $self->{jobs} };
 
 	return $self;
 }
@@ -102,10 +86,85 @@ sub run {
 	$self = $self->SUPER::run(%params);
 	$self = $self->_getStoredJobs();
 	$self = $self->_sortJobsByPriority();
+	$self = $self->_runJobs();
 
 	return $self;
 }
 
+sub _runJob {
+	my ( $self, $job ) = @_;
+	my $config     = ();
+	my $start_time = time;
+
+	try {
+		my $antivirus = $self->{jobj}->{task}->{antivirus}->{name};
+		my $task      = $job->{job_type};
+		my $class     = "Armadito::Agent::Task::$task";
+
+		if ( $self->{agent}->isTaskSpecificToAV($task) ) {
+			$class = "Armadito::Agent::Antivirus::" . $antivirus . "::Task::" . $task;
+		}
+
+		$class->require();
+		my $taskclass = $class->new( agent => $self->{agent}, job => $job );
+		$taskclass->run();
+	}
+	catch {
+		$self->{logger}->error($_);
+		$self->{jobj}->{task}->{obj} = {
+			code       => 1,
+			message    => encode_base64($_),
+			job_id     => $job->{job_id},
+			start_time => $start_time,
+			end_time   => time
+		};
+
+		return $self;
+	};
+
+	$self->{jobj}->{task}->{obj} = {
+		code       => 0,
+		message    => "runJob successful",
+		job_id     => $job->{job_id},
+		start_time => $start_time,
+		end_time   => time
+	};
+
+	return $self;
+}
+
+sub _runJobs {
+	my ($self) = @_;
+
+	foreach my $job ( @{ $self->{jobs} } ) {
+		$self->_runJob($job);
+		$self->_sendStatus();
+		$self->_rmJobFromStorage( $job->{job_id} );
+	}
+
+	return $self;
+}
+
+sub _sendStatus {
+	my ($self) = @_;
+
+	my $json_text = to_json( $self->{jobj} );
+
+	my $response = $self->{glpi_client}->sendRequest(
+		"url"   => $self->{agent}->{config}->{server}[0] . "/api/jobs",
+		message => $json_text,
+		method  => "POST"
+	);
+
+	if ( $response->is_success() ) {
+		$self->{logger}->info("Runjobs sendStatus successful...");
+	}
+	else {
+		$self->_handleError($response);
+		$self->{logger}->info("Runjobs sendStatus failed...");
+	}
+}
+
 1;
 
 __END__
@@ -120,10 +179,6 @@ This task inherits from L<Armadito::Agent::Task>. Run jobs and send results to /
 
 =head1 FUNCTIONS
 
-=head2 isEnabled ( $self )
-
-Returns true if the task is enabled.
-
 =head2 run ( $self, %params )
 
 Run the task.
