@@ -4,17 +4,9 @@ use strict;
 use warnings;
 use base 'Armadito::Agent::Task';
 
-use FusionInventory::Agent::Config;
-use FusionInventory::Agent::Logger;
 use Data::Dumper;
 use JSON;
 
-sub isEnabled {
-	my ($self) = @_;
-
-	return 1;
-}
-
 sub new {
 	my ( $class, %params ) = @_;
 
@@ -26,7 +18,7 @@ sub new {
 
 	my $task = {
 		name      => "State",
-		antivirus => ""
+		antivirus => $self->{agent}->{antivirus}->getJobj()
 	};
 
 	$self->{jobj}->{task} = $task;
@@ -34,14 +26,38 @@ sub new {
 	return $self;
 }
 
-sub _handleResponse {
-	my ( $self, $response ) = @_;
+sub _sendToGLPI {
+	my ( $self, $stateobj ) = @_;
 
-	$self->{logger}->info( "Successful Response : " . $response->content() );
-	my $obj = from_json( $response->content(), { utf8 => 1 } );
-	$self->{logger}->info( Dumper($obj) );
+	$self->{jobj}->{task}->{obj} = $stateobj;
+	my $json_text = to_json( $self->{jobj} );
 
-	return $self;
+	my $response = $self->{glpi_client}->sendRequest(
+		"url"   => $self->{agent}->{config}->{server}[0] . "/api/states",
+		message => $json_text,
+		method  => "POST"
+	);
+
+	if ( $response->is_success() ) {
+		$self->{logger}->info("Send AV State successful...");
+	}
+	else {
+		$self->_handleError($response);
+		$self->{logger}->info("Send AV State failed...");
+	}
+}
+
+sub _addAVDetail {
+	my ( $self, $attr, $value ) = @_;
+
+	$attr =~ s/^://;
+
+	my $avdetail = {
+		attr  => $attr,
+		value => $value
+	};
+
+	push( @{ $self->{data}->{avdetails} }, $avdetail );
 }
 
 sub _handleError {
@@ -54,14 +70,6 @@ sub _handleError {
 	return $self;
 }
 
-sub run {
-	my ( $self, %params ) = @_;
-
-	$self = $self->SUPER::run(%params);
-
-	return $self;
-}
-
 1;
 
 __END__
@@ -76,10 +84,6 @@ This task inherits from L<Armadito::Agent::Task>. Get Antivirus state and send i
 
 =head1 FUNCTIONS
 
-=head2 isEnabled ( $self )
-
-Returns true if the task is enabled.
-
 =head2 run ( $self, %params )
 
 Run the task.
